@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2009, 2013, 2015-2016, 2020-2021 Rocky Bernstein
+#  Copyright (C) 2009, 2013, 2015-2016, 2020-2021, 2024
+#  Rocky Bernstein
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -15,6 +16,8 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import pprint
+from typing import Callable
+
 from columnize import columnize
 
 # Maximum length of strings
@@ -33,7 +36,7 @@ def truncate_length(obj, length=MAX_PP_COUNT):
     """
     if isinstance(obj, dict):
         new_obj = dict((k[:length], v) for k, v in sorted(obj.items()))
-        # We hope zzz will be appear at the end of the sorted list.
+        # We hope zzz will appear at the end of the sorted list.
         new_obj.update({"zzz...": "..."})
         return new_obj
     elif hasattr(obj, "__getitem__"):
@@ -43,18 +46,21 @@ def truncate_length(obj, length=MAX_PP_COUNT):
 
 class SafePP(pprint.PrettyPrinter):
     def _format(self, obj, *args, **kwargs):
-        if isinstance(obj, str):
-            if len(obj) > MAX_PP_STRLEN:
-                obj = obj[:MAX_PP_STRLEN] + "..."
+        try:
+            if isinstance(obj, str):
+                if len(obj) > MAX_PP_STRLEN:
+                    obj = obj[:MAX_PP_STRLEN] + "..."
+                    pass
                 pass
+            elif hasattr(obj, "__len__") and len(obj) > MAX_PP_COUNT:
+                obj = truncate_length(obj)
+        except Exception:
             pass
-        elif hasattr(obj, "__len__") and len(obj) > MAX_PP_COUNT:
-            obj = truncate_length(obj)
 
         return pprint.PrettyPrinter._format(self, obj, *args, **kwargs)
 
 
-def pp(val, display_width, msg_nocr, msg, prefix=None):
+def pp(val, display_width, msg_nocr: Callable, msg: Callable, prefix=None):
     if prefix is not None:
         val_len = len(repr(val))
         if val_len + len(prefix) < display_width - 1:
@@ -76,7 +82,9 @@ def pp(val, display_width, msg_nocr, msg, prefix=None):
 
 # Actually... code like this should go in pformat.
 # Possibly some will go into columnize.
-def pprint_simple_array(val, displaywidth, msg_nocr, msg, lineprefix=""):
+def pprint_simple_array(
+    val, displaywidth, msg_nocr: Callable, msg: Callable, lineprefix=""
+) -> bool:
     """Try to pretty print a simple case where a list is not nested.
     Return True if we can do it and False if not."""
 
@@ -115,7 +123,7 @@ if __name__ == "__main__":
     def msg(m):
         print(m)
 
-    pprint_simple_array(range(50), 50, msg_nocr, msg)
+    assert pprint_simple_array(range(50), 50, msg_nocr, msg) is False
     pp([i for i in range(10)], 50, msg_nocr, msg)
     pp(locals(), 50, msg_nocr, msg)
     x = [i for i in range(10)]
@@ -125,6 +133,6 @@ if __name__ == "__main__":
     x = [i for i in range(30)]
     ll = locals().keys()
     for k in sorted(ll):
-        pp(eval(k), 80, msg_nocr, msg, prefix="%s =" % k)
+        pp(eval(k), 80, msg_nocr, msg, prefix=f"{k} =")
         pass
     pass
