@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2008-2009, 2013, 2015 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2008-2009, 2013, 2015, 2024 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ class InfoSource(Mbase_subcmd.DebuggerSubcommand):
             self.errmsg("No current source file.")
             return
         filename = self.core.canonic_filename(self.proc.curframe)
-        self.msg("Current Python file is %s" % self.core.filename(filename))
+        self.msg(f"Current Python file is {self.core.filename(filename)}")
         return False
 
     pass
